@@ -71,23 +71,21 @@ def prepdep(dep, basepath):
             dep.found = 1
         return
 
-    incs = []
-    lids = []
     IPREFIX = ' -I$(BASE)' if basepath else ' -I'
     LPREFIX = ' -L$(BASE)' if basepath else ' -L'
     startind = len(basepath) if basepath else 0
+    incs = []
     if dep.inc_dir:
         if isinstance(dep.inc_dir, str):
-            incs.append(IPREFIX+dep.inc_dir[startind:])
+            incs = [IPREFIX+dep.inc_dir[startind:]]
         else:
-            for dir in dep.inc_dir:
-                incs.append(IPREFIX+dir[startind:])
+            incs = [IPREFIX+dir[startind:] for dir in dep.inc_dir]
+    lids = []
     if dep.lib_dir:
         if isinstance(dep.lib_dir, str):
-            lids.append(LPREFIX+dep.lib_dir[startind:])
+            lids = [LPREFIX+dep.lib_dir[startind:]]
         else:
-            for dir in dep.lib_dir:
-                lids.append(LPREFIX+dir[startind:])
+            lids = [LPREFIX+dir[startind:]for dir in dep.lib_dir]
     libs = ''
     for lib in dep.libs:
         libs += ' -l' + lib
@@ -125,12 +123,11 @@ def writesetupfile(deps, basepath, additional_lines):
             parts = l.split()
             for al in additional_lines:
                 aparts = al.split()
-                if aparts and parts:
-                    if aparts[0] == parts[0]:
-                        #print('the same!' + repr(aparts) + repr(parts))
-                        #the same, we should not add the old one.
-                        #It will be overwritten by the new one.
-                        addit = 0
+                if (aparts and parts) and (aparts[0] == parts[0]):
+                    #print('the same!' + repr(aparts) + repr(parts))
+                    #the same, we should not add the old one.
+                    #It will be overwritten by the new one.
+                    addit = 0
             if addit:
                 new_lines.append(l)
 
@@ -142,7 +139,7 @@ def writesetupfile(deps, basepath, additional_lines):
         for line in lines:
             useit = 1
             if not line.startswith('COPYLIB') and not (line and line[0]=='#'):
-                lineDeps = set(re.findall(r'\$\([a-z0-9\w]+\)', line, re.I))
+                lineDeps = set(re.findall(r'\$\([\w]+\)', line, re.I))
                 if lineDeps.difference(legalVars):
                     newsetup.write('#'+line)
                     useit = 0
@@ -161,6 +158,9 @@ def main(auto=False):
     additional_platform_setup = []
     conan = "-conan" in sys.argv
 
+    setup_path = os.path.join(BASE_PATH, 'Setup')
+    backup_path = os.path.join(BASE_PATH, 'Setup.bak')
+
     if '-sdl2' in sys.argv:
         sys.argv.remove('-sdl2')
     if '-sdl1' in sys.argv:
@@ -212,7 +212,7 @@ Only SDL2 is supported now.""")
     if sys.platform == 'win32':
         additional_platform_setup = open(
             os.path.join(BASE_PATH, 'buildconfig', "Setup_Win_Camera.in")).readlines()
-    elif sys.platform == 'darwin':
+    if sys.platform == 'darwin':
         additional_platform_setup = open(
             os.path.join(BASE_PATH, 'buildconfig', "Setup_Darwin.in")).readlines()
     elif sysconfig.get_config_var('MACHDEP') == 'emscripten':
@@ -223,10 +223,13 @@ Only SDL2 is supported now.""")
             os.path.join(BASE_PATH, 'buildconfig', "Setup_Unix.in")).readlines()
 
 
-    if os.path.isfile('Setup'):
-        if auto:
+    if os.path.isfile(setup_path) and auto:
+        try:
             logging.info('Backing up existing "Setup" file into Setup.bak')
-            shutil.copyfile(os.path.join(BASE_PATH, 'Setup'), os.path.join(BASE_PATH, 'Setup.bak'))
+            shutil.copyfile(setup_path, backup_path)
+        except Exception as e:
+            logging.error(f"Failed to backup 'Setup' file: {e}")
+
 
     deps = CFG.main(**kwds, auto_config=auto)
     if '-conan' in sys.argv:
