@@ -2,7 +2,8 @@
 #define DOC_PYGAMECURSORS "pygame module for cursor resources"
 #define DOC_PYGAMECURSORSCOMPILE "compile(strings, black='X', white='.', xor='o') -> data, mask\ncreate binary cursor data from simple strings"
 #define DOC_PYGAMECURSORSLOADXBM "load_xbm(cursorfile) -> cursor_args\nload_xbm(cursorfile, maskfile) -> cursor_args\nload cursor data from an XBM file"
-#define DOC_PYGAMECURSORSCURSOR "Cursor(size, hotspot, xormasks, andmasks) -> Cursor\nCursor(hotspot, surface) -> Cursor\nCursor(constant) -> Cursor\npygame object representing a cursor"
+#define DOC_PYGAMECURSORSCURSOR "Cursor(size, hotspot, xormasks, andmasks) -> Cursor\nCursor(hotspot, surface) -> Cursor\nCursor(constant) -> Cursor\nCursor(Cursor) -> Cursor\nCursor() -> Cursor\npygame object representing a cursor"
+#define DOC_CURSORCOPY "copy() -> Cursor\ncopy the current cursor"
 #define DOC_CURSORTYPE "type -> string\nGets the cursor type"
 #define DOC_CURSORDATA "data -> tuple\nGets the cursor data"
 
@@ -27,8 +28,14 @@ pygame.cursors.Cursor
  Cursor(size, hotspot, xormasks, andmasks) -> Cursor
  Cursor(hotspot, surface) -> Cursor
  Cursor(constant) -> Cursor
+ Cursor(Cursor) -> Cursor
+ Cursor() -> Cursor
 pygame object representing a cursor
 
+pygame.cursors.Cursor.copy
+ copy() -> Cursor
+copy the current cursor
+
 pygame.cursors.Cursor.type
  type -> string
 Gets the cursor type
