@@ -1,6 +1,7 @@
 import collections
 import time
 import unittest
+import os
 
 import pygame
 
@@ -30,9 +31,9 @@ EVENT_TEST_PARAMS.update(
     {
         pygame.KEYDOWN: {"key": pygame.K_SPACE},
         pygame.KEYUP: {"key": pygame.K_SPACE},
-        pygame.MOUSEMOTION: dict(),
-        pygame.MOUSEBUTTONDOWN: dict(button=1),
-        pygame.MOUSEBUTTONUP: dict(button=1),
+        pygame.MOUSEMOTION: {},
+        pygame.MOUSEBUTTONDOWN: {"button": 1},
+        pygame.MOUSEBUTTONUP: {"button": 1},
     }
 )
 
@@ -72,23 +73,13 @@ NAMES_AND_EVENTS = (
     ("ControllerDeviceRemoved", pygame.CONTROLLERDEVICEREMOVED),
     ("ControllerDeviceMapped", pygame.CONTROLLERDEVICEREMAPPED),
     ("DropFile", pygame.DROPFILE),
+    ("AudioDeviceAdded", pygame.AUDIODEVICEADDED),
+    ("AudioDeviceRemoved", pygame.AUDIODEVICEREMOVED),
+    ("DropText", pygame.DROPTEXT),
+    ("DropBegin", pygame.DROPBEGIN),
+    ("DropComplete", pygame.DROPCOMPLETE),
 )
 
-# Add in any SDL 2.0.4 specific events.
-if pygame.get_sdl_version() >= (2, 0, 4):
-    NAMES_AND_EVENTS += (
-        ("AudioDeviceAdded", pygame.AUDIODEVICEADDED),
-        ("AudioDeviceRemoved", pygame.AUDIODEVICEREMOVED),
-    )
-
-# Add in any SDL 2.0.5 specific events.
-if pygame.get_sdl_version() >= (2, 0, 5):
-    NAMES_AND_EVENTS += (
-        ("DropText", pygame.DROPTEXT),
-        ("DropBegin", pygame.DROPBEGIN),
-        ("DropComplete", pygame.DROPCOMPLETE),
-    )
-
 
 class EventTypeTest(unittest.TestCase):
     def test_Event(self):
@@ -152,14 +143,26 @@ class EventTypeTest(unittest.TestCase):
         c = pygame.event.Event(EVENT_TYPES[1], a=1)
         d = pygame.event.Event(EVENT_TYPES[0], a=2)
 
-        self.assertTrue(a == a)
-        self.assertFalse(a != a)
-        self.assertTrue(a == b)
-        self.assertFalse(a != b)
-        self.assertTrue(a != c)
-        self.assertFalse(a == c)
-        self.assertTrue(a != d)
-        self.assertFalse(a == d)
+        # Comparing event a
+        self.assertEqual(a, a)  # Event is equal to itself
+        self.assertEqual(a, b)  # Same type and attributes
+        self.assertNotEqual(a, c)  # Different type but same attributes
+        self.assertNotEqual(a, d)  # Same type but different attributes
+
+        # Comparing event b
+        self.assertEqual(b, a)  # Same type and attributes
+        self.assertNotEqual(b, c)  # Different type but same attributes
+        self.assertNotEqual(b, d)  # Same type but different attributes
+
+        # Comparing event c
+        self.assertNotEqual(c, a)  # Different type but same attributes
+        self.assertNotEqual(c, b)  # Different type but same attributes
+        self.assertNotEqual(c, d)  # Different type and different attributes
+
+        # Comparing event d
+        self.assertNotEqual(d, a)  # Same type but different attributes
+        self.assertNotEqual(d, b)  # Same type but different attributes
+        self.assertNotEqual(d, c)  # Different type and different attributes
 
 
 race_condition_notification = """
@@ -647,6 +650,13 @@ class EventModuleTest(unittest.TestCase):
                 pygame.event.event_name(event), unexpected_name, f"0x{event:X}"
             )
 
+    def test_event_name__kwargs(self):
+        """Ensure event_name() returns the correct event name when kwargs used."""
+        for expected_name, event in NAMES_AND_EVENTS:
+            self.assertEqual(
+                pygame.event.event_name(type=event), expected_name, f"0x{event:X}"
+            )
+
     def test_peek(self):
         """Ensure queued events can be peeked at."""
         event_types = [pygame.KEYDOWN, pygame.KEYUP, pygame.MOUSEMOTION]
@@ -849,6 +859,22 @@ class EventModuleTest(unittest.TestCase):
             pygame.event.set_grab(i % 2)
             self.assertEqual(pygame.event.get_grab(), i % 2)
 
+    @unittest.skipIf(
+        os.environ.get("SDL_VIDEODRIVER") == "dummy",
+        "requires the SDL_VIDEODRIVER to be a non dummy value",
+    )
+    @unittest.skipIf(pygame.get_sdl_version() < (2, 0, 16), "Needs at least SDL 2.0.16")
+    def test_set_keyboard_grab_and_get_keyboard_grab(self):
+        """Ensure set_keyboard_grab() and get_keyboard_grab() work as expected"""
+
+        surf = pygame.display.set_mode((10, 10))
+
+        pygame.event.set_keyboard_grab(True)
+        self.assertTrue(pygame.event.get_keyboard_grab())
+
+        pygame.event.set_keyboard_grab(False)
+        self.assertFalse(pygame.event.get_keyboard_grab())
+
     def test_poll(self):
         """Ensure poll() works as expected"""
         pygame.event.clear()
